@@ -84,10 +84,14 @@ def sync_detailed(
             'Alias aut rerum fugiat exercitationem maiores.'}, 'incident_role_id':
             '01FH5TZRWMNAFB0DZ23FD1TV96'}, {'assignee': {'email': 'Dolore autem ea et voluptatem minus
             aut.', 'id': 'Ut doloribus porro et sit nihil.', 'slack_user_id': 'Alias aut rerum fugiat
-            exercitationem maiores.'}, 'incident_role_id': '01FH5TZRWMNAFB0DZ23FD1TV96'}],
-            'incident_type_id': 'Quidem amet.', 'name': 'Our database is sad', 'severity_id': 'Aut
-            quis.', 'summary': "Our database is really really sad, and we don't know why yet.",
-            'visibility': 'public'}.
+            exercitationem maiores.'}, 'incident_role_id': '01FH5TZRWMNAFB0DZ23FD1TV96'}, {'assignee':
+            {'email': 'Dolore autem ea et voluptatem minus aut.', 'id': 'Ut doloribus porro et sit
+            nihil.', 'slack_user_id': 'Alias aut rerum fugiat exercitationem maiores.'},
+            'incident_role_id': '01FH5TZRWMNAFB0DZ23FD1TV96'}], 'incident_type_id': 'Aut repellendus
+            voluptatem.', 'mode': 'real', 'name': 'Our database is sad', 'severity_id': 'Placeat quod
+            aspernatur quia eveniet.', 'source_message_channel_id': 'C02AW36C1M5',
+            'source_message_timestamp': '1653650280.526509', 'status': 'triage', 'summary': "Our
+            database is really really sad, and we don't know why yet.", 'visibility': 'public'}.
 
     Returns:
         Response[IncidentsCreateResponseBody]
@@ -143,10 +147,14 @@ def sync(
             'Alias aut rerum fugiat exercitationem maiores.'}, 'incident_role_id':
             '01FH5TZRWMNAFB0DZ23FD1TV96'}, {'assignee': {'email': 'Dolore autem ea et voluptatem minus
             aut.', 'id': 'Ut doloribus porro et sit nihil.', 'slack_user_id': 'Alias aut rerum fugiat
-            exercitationem maiores.'}, 'incident_role_id': '01FH5TZRWMNAFB0DZ23FD1TV96'}],
-            'incident_type_id': 'Quidem amet.', 'name': 'Our database is sad', 'severity_id': 'Aut
-            quis.', 'summary': "Our database is really really sad, and we don't know why yet.",
-            'visibility': 'public'}.
+            exercitationem maiores.'}, 'incident_role_id': '01FH5TZRWMNAFB0DZ23FD1TV96'}, {'assignee':
+            {'email': 'Dolore autem ea et voluptatem minus aut.', 'id': 'Ut doloribus porro et sit
+            nihil.', 'slack_user_id': 'Alias aut rerum fugiat exercitationem maiores.'},
+            'incident_role_id': '01FH5TZRWMNAFB0DZ23FD1TV96'}], 'incident_type_id': 'Aut repellendus
+            voluptatem.', 'mode': 'real', 'name': 'Our database is sad', 'severity_id': 'Placeat quod
+            aspernatur quia eveniet.', 'source_message_channel_id': 'C02AW36C1M5',
+            'source_message_timestamp': '1653650280.526509', 'status': 'triage', 'summary': "Our
+            database is really really sad, and we don't know why yet.", 'visibility': 'public'}.
 
     Returns:
         Response[IncidentsCreateResponseBody]
@@ -195,10 +203,14 @@ async def asyncio_detailed(
             'Alias aut rerum fugiat exercitationem maiores.'}, 'incident_role_id':
             '01FH5TZRWMNAFB0DZ23FD1TV96'}, {'assignee': {'email': 'Dolore autem ea et voluptatem minus
             aut.', 'id': 'Ut doloribus porro et sit nihil.', 'slack_user_id': 'Alias aut rerum fugiat
-            exercitationem maiores.'}, 'incident_role_id': '01FH5TZRWMNAFB0DZ23FD1TV96'}],
-            'incident_type_id': 'Quidem amet.', 'name': 'Our database is sad', 'severity_id': 'Aut
-            quis.', 'summary': "Our database is really really sad, and we don't know why yet.",
-            'visibility': 'public'}.
+            exercitationem maiores.'}, 'incident_role_id': '01FH5TZRWMNAFB0DZ23FD1TV96'}, {'assignee':
+            {'email': 'Dolore autem ea et voluptatem minus aut.', 'id': 'Ut doloribus porro et sit
+            nihil.', 'slack_user_id': 'Alias aut rerum fugiat exercitationem maiores.'},
+            'incident_role_id': '01FH5TZRWMNAFB0DZ23FD1TV96'}], 'incident_type_id': 'Aut repellendus
+            voluptatem.', 'mode': 'real', 'name': 'Our database is sad', 'severity_id': 'Placeat quod
+            aspernatur quia eveniet.', 'source_message_channel_id': 'C02AW36C1M5',
+            'source_message_timestamp': '1653650280.526509', 'status': 'triage', 'summary': "Our
+            database is really really sad, and we don't know why yet.", 'visibility': 'public'}.
 
     Returns:
         Response[IncidentsCreateResponseBody]
@@ -252,10 +264,14 @@ async def asyncio(
             'Alias aut rerum fugiat exercitationem maiores.'}, 'incident_role_id':
             '01FH5TZRWMNAFB0DZ23FD1TV96'}, {'assignee': {'email': 'Dolore autem ea et voluptatem minus
             aut.', 'id': 'Ut doloribus porro et sit nihil.', 'slack_user_id': 'Alias aut rerum fugiat
-            exercitationem maiores.'}, 'incident_role_id': '01FH5TZRWMNAFB0DZ23FD1TV96'}],
-            'incident_type_id': 'Quidem amet.', 'name': 'Our database is sad', 'severity_id': 'Aut
-            quis.', 'summary': "Our database is really really sad, and we don't know why yet.",
-            'visibility': 'public'}.
+            exercitationem maiores.'}, 'incident_role_id': '01FH5TZRWMNAFB0DZ23FD1TV96'}, {'assignee':
+            {'email': 'Dolore autem ea et voluptatem minus aut.', 'id': 'Ut doloribus porro et sit
+            nihil.', 'slack_user_id': 'Alias aut rerum fugiat exercitationem maiores.'},
+            'incident_role_id': '01FH5TZRWMNAFB0DZ23FD1TV96'}], 'incident_type_id': 'Aut repellendus
+            voluptatem.', 'mode': 'real', 'name': 'Our database is sad', 'severity_id': 'Placeat quod
+            aspernatur quia eveniet.', 'source_message_channel_id': 'C02AW36C1M5',
+            'source_message_timestamp': '1653650280.526509', 'status': 'triage', 'summary': "Our
+            database is really really sad, and we don't know why yet.", 'visibility': 'public'}.
 
     Returns:
         Response[IncidentsCreateResponseBody]
