@@ -17,7 +17,7 @@ class CustomFieldsCreateResponseBody:
             'Product'}, {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key':
             10, 'value': 'Product'}, {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0',
             'sort_key': 10, 'value': 'Product'}], 'required': 'never', 'show_before_closure': True, 'show_before_creation':
-            True, 'updated_at': '2021-08-17T13:28:57.801578Z'}}
+            True, 'show_in_announcement_post': True, 'updated_at': '2021-08-17T13:28:57.801578Z'}}
 
     Attributes:
         custom_field (CustomFieldResponseBody):  Example: {'created_at': '2021-08-17T13:28:57.801578Z', 'description':
@@ -26,8 +26,8 @@ class CustomFieldsCreateResponseBody:
             '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'}, {'custom_field_id':
             '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value': 'Product'},
             {'custom_field_id': '01FCNDV6P870EA6S7TK1DSYDG0', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'sort_key': 10, 'value':
-            'Product'}], 'required': 'never', 'show_before_closure': True, 'show_before_creation': True, 'updated_at':
-            '2021-08-17T13:28:57.801578Z'}.
+            'Product'}], 'required': 'never', 'show_before_closure': True, 'show_before_creation': True,
+            'show_in_announcement_post': True, 'updated_at': '2021-08-17T13:28:57.801578Z'}.
     """
 
     custom_field: CustomFieldResponseBody
